==> kapla-2.0.1.tgz: package/lib/core/NoComponent.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _construct(Parent, args, Class) { if (isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import { Handler } from '../events';
export var NoComponent =
/*#__PURE__*/
function (_Handler) {
  _inherits(NoComponent, _Handler);

  function NoComponent(context) {
    var _this;

    _classCallCheck(this, NoComponent);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(NoComponent).call(this, context));
    _this.context = context;
    var props = _this.scope.props;

    if (props) {
      for (var prop in props) {
        if (Object.prototype.hasOwnProperty.call(props, prop)) {
          if (_this[prop]) {
            _this.context.handleError("[".concat(prop, "] already exists!"), 'initializing props');
          } else {
            _this[prop] = props[prop];
          }
        }
      }
    }

    return _this;
  }

  _createClass(NoComponent, [{
    key: "remove",
    value: function remove() {
      this.context.module.destroyNoElement(this.slug);
    }
    /* eslint-disable no-empty-function, class-methods-use-this */

  }, {
    key: "init",
    value: function init() {}
  }, {
    key: "destroy",
    value: function destroy() {}
    /* eslint-enable no-empty-function, class-methods-use-this */

  }, {
    key: "scope",
    get: function get() {
      return this.context.scope;
    }
  }, {
    key: "slug",
    get: function get() {
      return this.scope.slug;
    }
  }]);

  return NoComponent;
}(Handler);
export var mixNoComponent = function mixNoComponent() {
  for (var _len = arguments.length, mixins = new Array(_len), _key = 0; _key < _len; _key++) {
    mixins[_key] = arguments[_key];
  }

  var base =
  /*#__PURE__*/
  function (_NoComponent) {
    _inherits(base, _NoComponent);

    function base() {
      var _this2;

      _classCallCheck(this, base);

      for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        args[_key2] = arguments[_key2];
      }

      var context = args[0],
          params = args.slice(1);
      _this2 = _possibleConstructorReturn(this, _getPrototypeOf(base).call(this, context));
      mixins.forEach(function (Mixin) {
        copyProps(_assertThisInitialized(_assertThisInitialized(_this2)), _construct(Mixin, _toConsumableArray(params)));
      });
      return _this2;
    }

    return base;
  }(NoComponent); // Copy all properties and symbols, filtering out some special ones


  var copyProps = function copyProps(target, source) {
    Object.getOwnPropertyNames(source).concat(Object.getOwnPropertySymbols(source)).forEach(function (prop) {
      if (!prop.match(/^(?:constructor|prototype|arguments|caller|name|bind|call|apply|toString|length)$/)) {
        Object.defineProperty(target, prop, Object.getOwnPropertyDescriptor(source, prop));
      }
    });
  }; // Outside contructor() to allow aggregation(A,B,C).staticFunction() to be called etc.


  mixins.forEach(function (mixin) {
    copyProps(base.prototype, mixin.prototype);
    copyProps(base, mixin);
  });
  return base;
};

==> kapla-2.1.1.tgz: package/lib/core/NoComponent.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _construct(Parent, args, Class) { if (isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import { Handler } from '../events';
export var NoComponent =
/*#__PURE__*/
function (_Handler) {
  _inherits(NoComponent, _Handler);

  function NoComponent(context) {
    var _this;

    _classCallCheck(this, NoComponent);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(NoComponent).call(this, context));
    _this.context = context;
    var props = _this.scope.props;

    if (props) {
      for (var prop in props) {
        if (Object.prototype.hasOwnProperty.call(props, prop)) {
          if (_this[prop]) {
            _this.context.handleError("[".concat(prop, "] already exists!"), 'initializing props');
          } else {
            _this[prop] = props[prop];
          }
        }
      }
    }

    return _this;
  }

  _createClass(NoComponent, [{
    key: "remove",
    value: function remove() {
      this.context.module.destroyNoElement(this.slug);
    }
    /* eslint-disable no-empty-function, class-methods-use-this */

  }, {
    key: "init",
    value: function init() {}
  }, {
    key: "destroy",
    value: function destroy() {}
    /* eslint-enable no-empty-function, class-methods-use-this */

  }, {
    key: "scope",
    get: function get() {
      return this.context.scope;
    }
  }, {
    key: "slug",
    get: function get() {
      return this.scope.slug;
    }
  }]);

  return NoComponent;
}(Handler);
export var mixNoComponent = function mixNoComponent() {
  for (var _len = arguments.length, mixins = new Array(_len), _key = 0; _key < _len; _key++) {
    mixins[_key] = arguments[_key];
  }

  var base =
  /*#__PURE__*/
  function (_NoComponent) {
    _inherits(base, _NoComponent);

    function base() {
      var _this2;

      _classCallCheck(this, base);

      for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        args[_key2] = arguments[_key2];
      }

      var context = args[0],
          params = args.slice(1);
      _this2 = _possibleConstructorReturn(this, _getPrototypeOf(base).call(this, context));
      mixins.forEach(function (Mixin) {
        copyProps(_assertThisInitialized(_this2), _construct(Mixin, _toConsumableArray(params)));
      });
      return _this2;
    }

    return base;
  }(NoComponent); // Copy all properties and symbols, filtering out some special ones


  var copyProps = function copyProps(target, source) {
    Object.getOwnPropertyNames(source).concat(Object.getOwnPropertySymbols(source)).forEach(function (prop) {
      if (!prop.match(/^(?:constructor|prototype|arguments|caller|name|bind|call|apply|toString|length)$/)) {
        Object.defineProperty(target, prop, Object.getOwnPropertyDescriptor(source, prop));
      }
    });
  }; // Outside contructor() to allow aggregation(A,B,C).staticFunction() to be called etc.


  mixins.forEach(function (mixin) {
    copyProps(base.prototype, mixin.prototype);
    copyProps(base, mixin);
  });
  return base;
};
